This simply fixes s/boundry/boundary/, which I wanted to do first
before some more regex refactoring I'm planning.

2013-11-06  Jonathan Wakely  <jwakely....@gmail.com>

        * include/bits/regex_automaton.h (_S_opcode_word_boundry): Rename to
        _S_opcode_word_boundary.
        * include/bits/regex_automaton.tcc: Likewise.
        * include/bits/regex_executor.h (__detail::_Executor::_M_word_boundry):
        Rename to _M_word_boundary.
        * include/bits/regex_executor.tcc: Likewise.

Tested x86_64-linux, committed to trunk.
commit 9c72a2889302b33b4e13643c11414e8278a9ba34
Author: Jonathan Wakely <jwakely....@gmail.com>
Date:   Wed Nov 6 09:13:10 2013 +0000

        * include/bits/regex_automaton.h (_S_opcode_word_boundry): Rename to
        _S_opcode_word_boundary.
        * include/bits/regex_automaton.tcc: Likewise.
        * include/bits/regex_executor.h (__detail::_Executor::_M_word_boundry):
        Rename to _M_word_boundary.
        * include/bits/regex_executor.tcc: Likewise.

diff --git a/libstdc++-v3/include/bits/regex_automaton.tcc 
b/libstdc++-v3/include/bits/regex_automaton.tcc
index c15e3e9..258d22d 100644
--- a/libstdc++-v3/include/bits/regex_automaton.tcc
+++ b/libstdc++-v3/include/bits/regex_automaton.tcc
@@ -93,7 +93,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
          __ostr << __id << " [label=\"" << __id << "\\nLINE_END \"];\n"
                 << __id << " -> " << _M_next << " [label=\"epsilon\"];\n";
          break;
-       case _S_opcode_word_boundry:
+       case _S_opcode_word_boundary:
          __ostr << __id << " [label=\"" << __id << "\\nWORD_BOUNDRY "
                 << _M_neg << "\"];\n"
                 << __id << " -> " << _M_next << " [label=\"epsilon\"];\n";
diff --git a/libstdc++-v3/include/bits/regex_executor.h 
b/libstdc++-v3/include/bits/regex_executor.h
index 12db47b..57b3108 100644
--- a/libstdc++-v3/include/bits/regex_executor.h
+++ b/libstdc++-v3/include/bits/regex_executor.h
@@ -138,7 +138,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
       }
 
       bool
-      _M_word_boundry(_State<_CharT, _TraitsT> __state) const;
+      _M_word_boundary(_State<_CharT, _TraitsT> __state) const;
 
       bool
       _M_lookahead(_State<_CharT, _TraitsT> __state);
diff --git a/libstdc++-v3/include/bits/regex_executor.tcc 
b/libstdc++-v3/include/bits/regex_executor.tcc
index 0c42189..b310aba 100644
--- a/libstdc++-v3/include/bits/regex_executor.tcc
+++ b/libstdc++-v3/include/bits/regex_executor.tcc
@@ -257,8 +257,8 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
          if (_M_at_end())
            _M_dfs<__match_mode>(__state._M_next);
          break;
-       case _S_opcode_word_boundry:
-         if (_M_word_boundry(__state) == !__state._M_neg)
+       case _S_opcode_word_boundary:
+         if (_M_word_boundary(__state) == !__state._M_neg)
            _M_dfs<__match_mode>(__state._M_next);
          break;
        // Here __state._M_alt offers a single start node for a sub-NFA.
@@ -344,11 +344,11 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
        }
     }
 
-  // Return whether now is at some word boundry.
+  // Return whether now is at some word boundary.
   template<typename _BiIter, typename _Alloc, typename _TraitsT,
     bool __dfs_mode>
     bool _Executor<_BiIter, _Alloc, _TraitsT, __dfs_mode>::
-    _M_word_boundry(_State<_CharT, _TraitsT> __state) const
+    _M_word_boundary(_State<_CharT, _TraitsT> __state) const
     {
       // By definition.
       bool __ans = false;

Reply via email to
diff --git a/libstdc++-v3/include/bits/regex_automaton.h 
b/libstdc++-v3/include/bits/regex_automaton.h
index 4fb5556..e630512 100644
--- a/libstdc++-v3/include/bits/regex_automaton.h
+++ b/libstdc++-v3/include/bits/regex_automaton.h
@@ -56,7 +56,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
       _S_opcode_backref,
       _S_opcode_line_begin_assertion,
       _S_opcode_line_end_assertion,
-      _S_opcode_word_boundry,
+      _S_opcode_word_boundary,
       _S_opcode_subexpr_lookahead,
       _S_opcode_subexpr_begin,
       _S_opcode_subexpr_end,
@@ -83,7 +83,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
          _StateIdT  _M_quant_index;
          // for _S_opcode_alternative or _S_opcode_subexpr_lookahead
          _StateIdT  _M_alt;
          // for _S_opcode_word_boundry or _S_opcode_subexpr_lookahead or
          // quantifiers(ungreedy if set true)
          bool       _M_neg;
        };
@@ -197,7 +197,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
       _StateIdT
       _M_insert_word_bound(bool __neg)
       {
-       _StateT __tmp(_S_opcode_word_boundry);
+       _StateT __tmp(_S_opcode_word_boundary);
        __tmp._M_neg = __neg;
        return _M_insert_state(__tmp);
       }
@@ -83,7 +83,7 @@ _GLIBCXX_BEGIN_NAMESPACE_VERSION
          // for _S_opcode_alternative or _S_opcode_subexpr_lookahead
          _StateIdT  _M_alt;
-         // for _S_opcode_word_boundry or _S_opcode_subexpr_lookahead or
+         // for _S_opcode_word_boundary or _S_opcode_subexpr_lookahead or
          // quantifiers(ungreedy if set true)
          bool       _M_neg;